# -*- coding: utf-8 -*-
"""flake8-checkstyle - a flake8 plugin to output Checkstyle XML reports."""

__author__ = """Daichi Kumagai"""
__email__ = 'd9magai@gmail.com'
__version__ = '0.1.0'


from .plugin import CheckstylePlugin

__all__ = (
    'CheckstylePlugin',
)
